<?php


class VPP_STUDIO {

	/**
	 * VPP_STUDIO constructor.
	 *
	 * @return bool|void
	 *
	 */
	public function __construct() {

		if ( ! is_admin() ) {
			return false;
		}

		add_action( 'init', array( $this, 'Init' ) );

	}

	/**
	 * Init
	 */
	public function Init() {

		/** do_action vpp studio init */
		do_action( 'vpp_studio_init' );

		$this->_Include();

		add_action( 'admin_menu', array( $this, 'Menu' ) );

		/** do_action vpp studio loaded */
		do_action( 'vpp_studio_loaded' );

	}

	/**
	 * Include Studio Files
	 */
	private function _Include() {

		include_once 'studio/ajax/VPP_AJAX_NONCE.php';
		include_once 'class/VPP_FUNCTION.php';
		include_once 'class/VPP_FIELD.php';

		/** Page */
		include_once 'studio/page/VPP_PAGE_VIDEO.php';
		include_once 'studio/page/VPP_PAGE_VIDEO_EDIT.php';
		if ( ! defined( 'VPP_PLUS' ) ) {
			include_once 'studio/page/VPP_PAGE_PRO_VERSION.php';
		}

		/** Popup */
		include_once 'studio/ajax/VPP_AJAX_POPUP.php';
		include_once 'studio/ajax/VPP_AJAX_POPUP_CREATE.php';
		include_once 'studio/ajax/VPP_AJAX_POPUP_SETTING.php';
		include_once 'studio/ajax/VPP_AJAX_POPUP_ABOUT_ME.php';

		/** Ajax */
		include_once 'studio/ajax/VPP_AJAX_VIDEO_SEARCH.php';
		include_once 'studio/ajax/VPP_AJAX_VIDEO_SAVE.php';
		include_once 'studio/ajax/VPP_AJAX_VIDEO_UPDATE.php';
		include_once 'studio/ajax/VPP_AJAX_VIDEO_DELETE.php';
		include_once 'studio/ajax/VPP_AJAX_VIDEO_DELETE_GROUP.php';
		include_once 'studio/ajax/VPP_AJAX_SETTING_SAVE.php';

	}

	/**
	 * Create Menu
	 */
	public function Menu() {

		$title = apply_filters( 'vpp_studio_admin_menu_title', __( 'Video Land', VPP_TEXT_DOMAIN ) );

		add_menu_page( $title, $title, 'manage_options', 'vpp',
			array(
				$this,
				'Render'
			),
			'dashicons-youtube'
		);

		/** do_action vpp studio admin menu */
		do_action( 'vpp_studio_admin_menu' );

	}

	/**
	 * Render
	 */
	public function Render() {

		/** do_action vpp studio admin menu callback */
		do_action( 'vpp_studio_admin_menu_callback' );

		wp_enqueue_style( 'vpp_roboto', VPP_PLUGIN_CSS . 'vpp-roboto.css' );
		wp_enqueue_style( 'vpp_field', VPP_PLUGIN_CSS . 'vpp-field.css' );
		wp_enqueue_style( 'vpp_studio', VPP_PLUGIN_CSS . 'vpp-studio.css' );
		wp_enqueue_style( 'vpp_studio_resp', VPP_PLUGIN_CSS . 'vpp-studio-resp.css' );
		wp_enqueue_style( 'vpp_notification_style', VPP_PLUGIN_CSS . 'vpp-notification.css' );

		if ( is_rtl() ) {
			wp_enqueue_style( 'vpp_rtl_studio', VPP_PLUGIN_CSS . 'vpp-rtl-studio.css' );
		}

		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'vpp_studio_fields', VPP_PLUGIN_JS . 'vpp-studio-fields.js', array(), '1.0.0' );
		wp_enqueue_script( 'vpp_studio_script', VPP_PLUGIN_JS . 'vpp-studio.js', array(), '1.0.0' );
		wp_enqueue_script( 'vpp_notification', VPP_PLUGIN_JS . 'vpp-notification.js', array(), '1.0.0' );
		wp_enqueue_script( 'vpp_popup', VPP_PLUGIN_JS . 'vpp-popup.js', array(), '1.0.0' );
		wp_enqueue_media();

		$localize = [
			'AjaxUrl' => admin_url( 'admin-ajax.php' ),
			'Nonce'   => wp_create_nonce( VPP::$nonce ),
		];
		$translate = [
			'popup_create_title'                       => __( 'Create Video', VPP_TEXT_DOMAIN ),
			'popup_create_publish_btn'                 => __( 'Publish', VPP_TEXT_DOMAIN ),
			'popup_setting_title'                      => __( 'Setting', VPP_TEXT_DOMAIN ),
			'popup_setting_cancel'                     => __( 'Cancel', VPP_TEXT_DOMAIN ),
			'popup_setting_save'                       => __( 'Save', VPP_TEXT_DOMAIN ),
			'popup_about_title'                        => __( 'About IdeaLand', VPP_TEXT_DOMAIN ),
			'notification_delete_video_title'          => __( 'Will the Video be deleted?', VPP_TEXT_DOMAIN ),
			'notification_delete_video_selector_title' => __( 'Do you want to delete the selected videos?', VPP_TEXT_DOMAIN ),
			'notification_delete_playlist_title'       => __( 'Will the Playlist be deleted?', VPP_TEXT_DOMAIN ),
			'notification_delete_playlist_video_title' => __( 'Will the Video be removed from the Playlist?', VPP_TEXT_DOMAIN ),
			'notification_video_update_title'          => __( 'Video Updated', VPP_TEXT_DOMAIN ),
			'notification_subtitle_update_title'       => __( 'Subtitle Updated', VPP_TEXT_DOMAIN ),
			'notification_ok'                          => __( 'OK', VPP_TEXT_DOMAIN ),
			'notification_cancel'                      => __( 'Cancel', VPP_TEXT_DOMAIN ),
		];
		wp_localize_script( 'vpp_studio_script', 'vpp_ajax_config', $localize );
		wp_localize_script( 'vpp_studio_script', 'VPP_TRANSLATE', $translate );

		require 'studio/render-studio-header.php';
		require 'studio/render-studio-left-nav.php';
		require 'studio/render-studio-container.php';

	}

}

new VPP_STUDIO();