<?php

// Check nonce
class VPP_FIELD {

	const __save = 'vpp--save';
	const __boxed = 'vpp-field-boxed';

	private static $class = [];
	private static $type = '';
	private static $arg = [];

	/**
	 * TextBox
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          help: String
	 *          value: String
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function TextBox( $arg ) {

		self::$arg = $arg;
		self::$type = 'text';
		self::$class[] = self::__boxed;

		self::Frame_Field_Start();
		self::Label();
		self::Input(
			[
				'type'  => 'text',
				'class' => [
					self::__save
				],
				'name'  => self::Arg( 'name' ),
				'value' => self::Arg( 'value' ),
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Text Area
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          placeholder: String
	 *          help: String
	 *          value: String
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Text_Area( $arg ) {

		self::$arg = $arg;
		self::$type = 'text-area';
		self::$class[] = self::__boxed;

		self::Frame_Field_Start();
		self::Label();
		?>

        <textarea class="<?php echo esc_attr( self::__save ); ?>"
                  id="<?php echo esc_attr( self::Arg( 'name' ) ); ?>"
                  placeholder="<?php echo esc_attr( self::Arg( 'placeholder' ) ); ?>"
                  name="<?php echo esc_attr( self::Arg( 'name' ) ); ?>"><?php echo esc_html( self::Arg( 'value' ) ); ?></textarea>

		<?php
		self::Frame_Field_End();

	}

	/**
	 * Select
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          help: String
	 *          selected: String
	 *          options:
	 *              [
	 *                  $value: $text
	 *              ]
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Select( $arg ) {

		self::$arg = $arg;
		self::$type = 'select';
		self::$class[] = self::__boxed;

		self::Frame_Field_Start();
		self::Label();
		?>

        <select class="<?php echo esc_attr( self::__save ); ?>"
                id="<?php echo esc_attr( self::Arg( 'name' ) ); ?>"
                name="<?php echo esc_attr( self::Arg( 'name' ) ); ?>">

            <option value=""><?php echo __( 'Select', VPP_TEXT_DOMAIN ); ?></option>
			<?php foreach ( self::CheckArray( self::Arg( 'options' ) ) as $index => $value ): ?>

                <option value="<?php echo esc_attr( $index ); ?>"
					<?php echo self::Arg( 'selected' ) && self::Arg( 'selected' ) == $index ? 'selected="selected"' : null ?>>
					<?php echo esc_attr( $value ); ?>
                </option>

			<?php endforeach; ?>
        </select>

		<?php
		self::Frame_Field_End();

	}

	/**
	 * Thumbnail
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          description: String
	 *          value: String
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Thumbnail( $arg ) {

		self::$arg = $arg;
		self::$type = 'thumbnail';
		self::$class = [];

		self::Frame_Field_Start();
		self::Heading();
		?>

        <div class="ytpl-select">
            <div>
				<?php echo VPP_ICON::$add_image; ?>
                <span><?php echo __( 'Select Thumbnail', VPP_TEXT_DOMAIN ); ?></span>
            </div>
        </div>
        <div class="ytpl-media">
			<?php

			if ( self::Arg( 'value' ) ): ?>

                <div class="ytpl-image"
                     style="background:url(<?php echo esc_url( wp_get_attachment_image_url( self::Arg( 'value' ), 'full' ) ); ?>)"></div>

			<?php endif;

			?>
        </div>
        <div class="clear"></div>

		<?php
		self::Input(
			[
				'type'  => 'hidden',
				'name'  => 'thumbnail',
				'class' => [
					self::__save
				],
				'value' => self::Arg( 'value' )
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Subtitle
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          description: String
	 *          data: String|JsonData
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Subtitle( $arg ) {

		self::$arg = $arg;
		self::$type = 'subtitle';
		self::$class = [];
		$options = [
			'af'     => 'Afrikaans',
			'am'     => 'Amharic - አማርኛ',
			'an'     => 'Aragonese - aragonés',
			'ar'     => 'Arabic - العربية',
			'ast'    => 'Asturian - asturianu',
			'az'     => 'Azerbaijani - azərbaycan dili',
			'be'     => 'Belarusian - беларуская',
			'bg'     => 'Bulgarian - български',
			'bn'     => 'Bengali - বাংলা',
			'br'     => 'Breton - brezhoneg',
			'bs'     => 'Bosnian - bosanski',
			'ca'     => 'Catalan - català',
			'ckb'    => 'Central Kurdish - کوردی (دەستنوسی عەرەبی)',
			'co'     => 'Corsican',
			'cs'     => 'Czech - čeština',
			'cy'     => 'Welsh - Cymraeg',
			'da'     => 'Danish - dansk',
			'de'     => 'German - Deutsch',
			'de-AT'  => 'German (Austria) - Deutsch (Österreich)',
			'de-CH'  => 'German (Switzerland) - Deutsch (Schweiz)',
			'de-DE'  => 'German (Germany) - Deutsch (Deutschland)',
			'de-LI'  => 'German (Liechtenstein) - Deutsch (Liechtenstein)',
			'el'     => 'Greek - Ελληνικά',
			'en'     => 'English',
			'en-AU'  => 'English (Australia)',
			'en-CA'  => 'English (Canada)',
			'en-GB'  => 'English (United Kingdom)',
			'en-IN'  => 'English (India)',
			'en-NZ'  => 'English (New Zealand)',
			'en-US'  => 'English (United States)',
			'en-ZA'  => 'English (South Africa)',
			'eo'     => 'Esperanto - esperanto',
			'es'     => 'Spanish - español',
			'es-419' => 'Spanish (Latin America) - español (Latinoamérica)',
			'es-AR'  => 'Spanish (Argentina) - español (Argentina)',
			'es-ES'  => 'Spanish (Spain) - español (España)',
			'es-MX'  => 'Spanish (Mexico) - español (México)',
			'es-US'  => 'Spanish (United States) - español (Estados Unidos)',
			'et'     => 'Estonian - eesti',
			'eu'     => 'Basque - euskara',
			'fa'     => 'Persian - فارسی',
			'fi'     => 'Finnish - suomi',
			'fil'    => 'Filipino',
			'fo'     => 'Faroese - føroyskt',
			'fr'     => 'French - français',
			'fr-CA'  => 'French (Canada) - français (Canada)',
			'fr-CH'  => 'French (Switzerland) - français (Suisse)',
			'fr-FR'  => 'French (France) - français (France)',
			'fy'     => 'Western Frisian',
			'ga'     => 'Irish - Gaeilge',
			'gd'     => 'Scottish Gaelic',
			'gl'     => 'Galician - galego',
			'gn'     => 'Guarani',
			'gu'     => 'Gujarati - ગુજરાતી',
			'ha'     => 'Hausa',
			'haw'    => 'Hawaiian - ʻŌlelo Hawaiʻi',
			'he'     => 'Hebrew - עברית',
			'hi'     => 'Hindi - हिन्दी',
			'hr'     => 'Croatian - hrvatski',
			'hu'     => 'Hungarian - magyar',
			'hy'     => 'Armenian - հայերեն',
			'ia'     => 'Interlingua',
			'id'     => 'Indonesian - Indonesia',
			'is'     => 'Icelandic - íslenska',
			'it'     => 'Italian - italiano',
			'it-CH'  => 'Italian (Switzerland) - italiano (Svizzera)',
			'it-IT'  => 'Italian (Italy) - italiano (Italia)',
			'ja'     => 'Japanese - 日本語',
			'ka'     => 'Georgian - ქართული',
			'kk'     => 'Kazakh - қазақ тілі',
			'km'     => 'Khmer - ខ្មែរ',
			'kn'     => 'Kannada - ಕನ್ನಡ',
			'ko'     => 'Korean - 한국어',
			'ku'     => 'Kurdish - Kurdî',
			'ky'     => 'Kyrgyz - кыргызча',
			'la'     => 'Latin',
			'ln'     => 'Lingala - lingála',
			'lo'     => 'Lao - ລາວ',
			'lt'     => 'Lithuanian - lietuvių',
			'lv'     => 'Latvian - latviešu',
			'mk'     => 'Macedonian - македонски',
			'ml'     => 'Malayalam - മലയാളം',
			'mn'     => 'Mongolian - монгол',
			'mo'     => 'Romanian (Moldova) - română (Moldova)',
			'mr'     => 'Marathi - मराठी',
			'ms'     => 'Malay - Bahasa Melayu',
			'mt'     => 'Maltese - Malti',
			'nb'     => 'Norwegian Bokmål - norsk bokmål',
			'ne'     => 'Nepali - नेपाली',
			'nl'     => 'Dutch - Nederlands',
			'nn'     => 'Norwegian Nynorsk - nynorsk',
			'no'     => 'Norwegian - norsk',
			'oc'     => 'Occitan',
			'om'     => 'Oromo - Oromoo',
			'or'     => 'Oriya - ଓଡ଼ିଆ',
			'pa'     => 'Punjabi - ਪੰਜਾਬੀ',
			'pl'     => 'Polish - polski',
			'ps'     => 'Pashto - پښتو',
			'pt'     => 'Portuguese - português',
			'pt-BR'  => 'Portuguese (Brazil) - português (Brasil)',
			'pt-PT'  => 'Portuguese (Portugal) - português (Portugal)',
			'qu'     => 'Quechua',
			'rm'     => 'Romansh - rumantsch',
			'ro'     => 'Romanian - română',
			'ru'     => 'Russian - русский',
			'sd'     => 'Sindhi',
			'sh'     => 'Serbo-Croatian - Srpskohrvatski',
			'si'     => 'Sinhala - සිංහල',
			'sk'     => 'Slovak - slovenčina',
			'sl'     => 'Slovenian - slovenščina',
			'sn'     => 'Shona - chiShona',
			'so'     => 'Somali - Soomaali',
			'sq'     => 'Albanian - shqip',
			'sr'     => 'Serbian - српски',
			'st'     => 'Southern Sotho',
			'su'     => 'Sundanese',
			'sv'     => 'Swedish - svenska',
			'sw'     => 'Swahili - Kiswahili',
			'ta'     => 'Tamil - தமிழ்',
			'te'     => 'Telugu - తెలుగు',
			'tg'     => 'Tajik - тоҷикӣ',
			'th'     => 'Thai - ไทย',
			'ti'     => 'Tigrinya - ትግርኛ',
			'tk'     => 'Turkmen',
			'to'     => 'Tongan - lea fakatonga',
			'tr'     => 'Turkish - Türkçe',
			'tt'     => 'Tatar',
			'tw'     => 'Twi',
			'ug'     => 'Uyghur',
			'uk'     => 'Ukrainian - українська',
			'ur'     => 'Urdu - اردو',
			'uz'     => 'Uzbek - o‘zbek',
			'vi'     => 'Vietnamese - Tiếng Việt',
			'wa'     => 'Walloon - wa',
			'xh'     => 'Xhosa',
			'yi'     => 'Yiddish',
			'yo'     => 'Yoruba - Èdè Yorùbá',
			'zh'     => 'Chinese - 中文',
			'zh-CN'  => 'Chinese (Simplified) - 中文（简体）',
			'zh-HK'  => 'Chinese (Hong Kong) - 中文（香港）',
			'zh-TW'  => 'Chinese (Traditional) - 中文（繁體）',
			'zu'     => 'Zulu - isiZulu',
		];

		self::Frame_Field_Start();
		self::Heading();
		?>

        <button>
			<?php echo __( 'Add Language', VPP_TEXT_DOMAIN ); ?>
			<?php echo VPP_ICON::$x; ?>
        </button>
        <div class="ytpl_subtitle_items">
			<?php

			if ( ! empty( self::Arg( 'data' ) ) ):
				foreach ( self::Arg( 'data' )[0]['value'] as $index => $value ): ?>

                    <div class="ytpl-item">
                        <div class="ytpl-field ytpl-field-select">
                            <label><?php echo __( 'Language', VPP_TEXT_DOMAIN ); ?></label>
                            <select>
								<?php foreach ( $options as $_index => $_value ): ?>
                                    <option value="<?php echo esc_html( $_index ); ?>" <?php echo $_index == $value['lang'] ? 'selected="selected"' : null; ?>><?php echo esc_html( $_value ); ?></option>
								<?php endforeach; ?>
                            </select>
                        </div>
                        <div class="ytpl-subtitle-selector"><?php

							$file_url = wp_get_attachment_url( $value['file'] );
							if ( ! empty( $file_url ) ) {

								$filename = explode( '/', $file_url );
								echo $filename[ count( $filename ) - 1 ];

							}

							?></div>
                        <div class="ytpl-subtitle-delete"><?php echo VPP_ICON::$trash; ?></div>

						<?php
						self::Input(
							[
								'type'  => 'hidden',
								'name'  => esc_attr( $index ),
								'class' => [
									self::__save
								],
								'value' => json_encode(
									[
										'lang' => $value['lang'],
										'file' => $value['file']
									]
								)
							]
						);
						?>
                    </div>
				<?php endforeach;
			endif;

			?>
        </div>

		<?php
		self::Input(
			[
				'type'  => 'hidden',
				'name'  => 'subtitle',
				'class' => [
					self::__save
				],
				'value' => self::Arg( 'value' )
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Editor
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Editor( $arg ) {

		self::$arg = $arg;
		self::$type = 'editor';
		self::$class = [];
        $video_url = '';
		$is_url = false;

		// check is not empty
		if(!empty(self::Arg( 'video' ))){
			// check is id or url
			if(is_numeric(self::Arg( 'video' ))){
				$video_url = wp_get_attachment_url( self::Arg( 'video' ) );
			}else{
				$video_url = self::Arg( 'video' );
				$is_url = true;
			}
		}

		$video_meta = wp_get_attachment_metadata( self::Arg( 'video' ) );
		$minute = floor( $video_meta['length'] / 60 );
		$data = self::Arg( 'data' );

		self::Frame_Field_Start();
		?>

        <div class="ytpl-video-controller-preview">
            <div class="ytpl-video-controller">

                <button class="ytpl-add cart">
					<?php
					echo VPP_ICON::$plus;
					echo __( 'Add Cart', VPP_TEXT_DOMAIN );
					?>
                </button>
                <div class="ytpl-cart-options ytpl-options">
					<?php

					if ( empty( $data ) || empty( $data['cart'] ) ):?>

                        <div class="ytpl-empty">
							<?php echo __( 'Empty Carts', VPP_TEXT_DOMAIN ); ?>
                        </div>

					<?php else:
						foreach ( $data['cart'] as $index => $cart ): ?>

                            <div class="ytpl-option" data-id="<?php echo esc_attr( $index ); ?>" data-type="cart">
                                <div class="ytpl-heading">
									<?php
									echo esc_html( $cart['type'] ) . ' - ' . $index;
									echo VPP_ICON::$trash;
									?>
                                </div>
                                <div class="ytpl-content">
                                    <label>
                                        <span><?php echo __( 'Title', VPP_TEXT_DOMAIN ); ?></span>
                                        <input type="text" name="title"
                                               value="<?php echo esc_html( $cart['title'] ); ?>">
                                    </label>
                                    <label style="width: 50%; float: left;">
                                        <span><?php echo __( 'Start', VPP_TEXT_DOMAIN ); ?></span>
                                        <div style="display: flex">
                                            <div style="flex: none">
												<?php echo gmdate( 'H:i:s', $cart['start'] ); ?>
                                            </div>
                                            <div style="flex: auto">
                                                <button class="ytpl-set-time"><?php echo __( 'Set Current Time', VPP_TEXT_DOMAIN ); ?></button>
                                            </div>
                                        </div>
                                        <input type="hidden" name="start"
                                               value="<?php echo esc_html( $cart['start'] ); ?>">
                                    </label>
                                    <label style="width: 50%; float: left;">
                                        <span><?php echo __( 'End', VPP_TEXT_DOMAIN ); ?></span>
                                        <div style="display: flex">
                                            <div style="flex: none">
												<?php echo gmdate( 'H:i:s', $cart['end'] ); ?>
                                            </div>
                                            <div style="flex: auto">
                                                <button class="ytpl-set-time"><?php echo __( 'Set Current Time', VPP_TEXT_DOMAIN ); ?></button>
                                            </div>
                                        </div>
                                        <input type="hidden" name="end" value="<?php echo esc_html( $cart['end'] ); ?>">
                                    </label>
                                    <label>
                                        <span><?php echo esc_html( $cart['type'] == 'link' ? 'Link' : ( $cart['type'] == 'video' ? 'Video ID' : 'Playlist ID' ) ); ?></span>
                                        <input type="text" name="<?php echo esc_html( $cart['type'] ); ?>"
                                               value="<?php echo esc_html( $cart[ $cart['type'] ] ); ?>">
                                    </label>
                                    <input type="hidden" name="type" value="<?php echo esc_html( $cart['type'] ); ?>">
                                </div>
                            </div>

						<?php endforeach;
					endif;

					?>
                </div>
                <button class="ytpl-add end-screen">
					<?php
					echo VPP_ICON::$plus;
					echo __( 'Add End Screen', VPP_TEXT_DOMAIN );
					?>
                </button>
                <div class="ytpl-end-screen-options ytpl-options">
					<?php

					if ( empty( $data ) || empty( $data['end_screen'] ) ):?>

                        <div class="ytpl-empty">
							<?php echo __( 'Empty Carts', VPP_TEXT_DOMAIN ); ?>
                        </div>

					<?php else:

						foreach ( $data['end_screen'] as $index_end => $end_screen ): ?>

                            <div class="ytpl-option" data-id="<?php echo esc_attr( $index_end ); ?>"
                                 data-type="end_screen">
                                <div class="ytpl-heading">
									<?php
									echo __( 'End Screen', VPP_TEXT_DOMAIN ) . ' - ' . $index_end;
									echo VPP_ICON::$trash;
									?>
                                </div>
                                <div class="ytpl-content">
                                    <label>
                                        <span><?php echo __( 'Layout', VPP_TEXT_DOMAIN ); ?></span>
                                        <select name="layout">
                                            <option <?php echo $end_screen['layout'] == 'last' ? 'selected="selected"' : null; ?>
                                                    value="last"><?php echo __( 'Last Video', VPP_TEXT_DOMAIN ); ?></option>
                                            <option <?php echo $end_screen['layout'] == 'top' ? 'selected="selected"' : null; ?>
                                                    value="top"><?php echo __( 'Top Video', VPP_TEXT_DOMAIN ); ?></option>
                                            <option <?php echo $end_screen['layout'] == 'last-top' ? 'selected="selected"' : null; ?>
                                                    value="last-top"><?php echo __( 'Last And Top Video', VPP_TEXT_DOMAIN ); ?></option>
                                            <option <?php echo $end_screen['layout'] == 'last-user' ? 'selected="selected"' : null; ?>
                                                    value="last-user"><?php echo __( 'Last Video And User', VPP_TEXT_DOMAIN ); ?></option>
                                            <option <?php echo $end_screen['layout'] == 'top-user' ? 'selected="selected"' : null; ?>
                                                    value="top-user"><?php echo __( 'Top Video And User', VPP_TEXT_DOMAIN ); ?></option>
                                            <option <?php echo $end_screen['layout'] == 'user' ? 'selected="selected"' : null; ?>
                                                    value="user"><?php echo __( 'User', VPP_TEXT_DOMAIN ); ?></option>
                                        </select>
                                    </label>
                                    <label style="width: 50%; float: left;">
                                        <span><?php echo __( 'Start', VPP_TEXT_DOMAIN ); ?></span>
                                        <div style="display: flex">
                                            <div style="flex: none">
												<?php echo gmdate( 'H:i:s', $end_screen['start'] ); ?>
                                            </div>
                                            <div style="flex: auto">
                                                <button class="ytpl-set-time"><?php echo __( 'Set Current Time', VPP_TEXT_DOMAIN ); ?></button>
                                            </div>
                                        </div>
                                        <input type="hidden" name="start"
                                               value="<?php echo esc_html( $end_screen['start'] ); ?>">
                                    </label>
                                    <label style="width: 50%; float: left;">
                                        <span><?php echo __( 'End', VPP_TEXT_DOMAIN ); ?></span>
                                        <div style="display: flex">
                                            <div style="flex: none">
												<?php echo gmdate( 'H:i:s', $video_meta['length'] ); ?>
                                            </div>
                                        </div>
                                        <input type="hidden" name="end"
                                               value="<?php echo esc_html( isset( $video_meta['length'] ) ? $video_meta['length'] : 0 ); ?>">
                                    </label>
                                </div>
                            </div>

						<?php endforeach;
					endif;

					?>
                </div>

            </div>
            <div class="ytpl-video-preview">
                <video>
                    <source src="<?php echo esc_url( wp_get_attachment_url( self::Arg( 'video' ) ) ); ?>"
                            type="video/mp4">
                </video>
                <div class="ytpl-overlay"></div>
                <button class="ytpl-button">
					<?php
					echo VPP_ICON::$play;
					echo VPP_ICON::$pause;
					?>
                </button>
            </div>
            <div class="clear"></div>
        </div>
        <div class="ytpl-time-line">
            <div class="ytpl-time-line-content">
                <div class="ytpl-row" style="align-items: flex-end">
                    <div class="ytpl-detail"></div>
                    <div class="ytpl-graphic-render">
						<?php

						for ( $a = 1; $a <= $minute; $a ++ ): ?>
                            <div class="ytpl-time"><?php echo gmdate( 'H:i:s', $a * 60 ); ?></div>
						<?php endfor;

						?>
                        <div class="ytpl-time"><?php echo gmdate( 'H:i:s', $video_meta['length'] ); ?></div>
						<?php

						?>
                        <div class="ytpl-current-pointer">
                            <span>00:00:00</span>
                        </div>
                        <div class="ytpl-event-layer"></div>
                    </div>
                </div>
                <div class="ytpl-row" data-line="video">
                    <div class="ytpl-detail">
						<?php echo VPP_ICON::$video; ?>
                        <span>
                        <?php echo __( 'Video', VPP_TEXT_DOMAIN ); ?>
                    </span>
                    </div>
                    <div class="ytpl-graphic-render">
                        <div class="ytpl-section"
                             style="left:0; width:<?php echo esc_html( $video_meta['length'] * 2 ); ?>px;">
                            <div class="ytpl-label">
								<?php echo __( 'video', VPP_TEXT_DOMAIN ); ?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="ytpl-row">
                    <div class="ytpl-detail">
						<?php echo VPP_ICON::$info; ?>
                        <span>
                        <?php echo __( 'Cart', VPP_TEXT_DOMAIN ); ?>
                    </span>
                    </div>
                    <div class="ytpl-graphic-render">
						<?php

						if ( ! empty( $data['cart'] ) ):
							foreach ( $data['cart'] as $index => $cart ): ?>

                                <div class="ytpl-section"
                                     style="left:<?php echo esc_attr( $cart['start'] * 2 ); ?>px; width:<?php echo esc_attr( ( $cart['end'] - $cart['start'] ) * 2 ); ?>px;"
                                     title="<?php echo esc_attr( $cart['title'] ); ?>"
                                     data-id="<?php echo esc_attr( $index ); ?>">
                                    <div class="ytpl-label">
										<?php echo esc_html( $cart['title'] ); ?>
                                    </div>
                                </div>

							<?php endforeach;
						endif;

						?>
                    </div>
                </div>
                <div class="ytpl-row">
                    <div class="ytpl-detail">
						<?php echo VPP_ICON::$link; ?>
                        <span>
                        <?php echo __( 'End screen', VPP_TEXT_DOMAIN ); ?>
                    </span>
                    </div>
                    <div class="ytpl-graphic-render">
						<?php

						if ( ! empty( $data['end_screen'] ) ):
							foreach ( $data['end_screen'] as $index => $end_screen ): ?>

                                <div class="ytpl-section"
                                     style="left:<?php echo esc_attr( $end_screen['start'] * 2 ); ?>px; width:<?php echo esc_attr( ( $video_meta['length'] - $end_screen['start'] ) * 2 ); ?>px;"
                                     data-id="<?php echo esc_attr( $index ); ?>">
                                    <div class="ytpl-label">
										<?php echo __( 'End Screen', VPP_TEXT_DOMAIN ); ?>
                                    </div>
                                </div>

							<?php endforeach;
						endif;

						?>
                    </div>
                </div>
            </div>
        </div>
        <script> YTPL_STUDIO_EDITOR_CONFIG(); </script>

		<?php

		self::Input(
			[
				'type'  => 'hidden',
				'name'  => esc_attr( self::Arg( 'name' ) ),
				'value' => json_encode( $data ),
				'class' => [
					self::__save
				]
			]
		);

		self::Frame_Field_End();

	}

	/**
	 * Element
	 *
	 *      [
	 *          name: String
	 *          video: String
	 *          data: String|JsonData
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Element( $arg ) {

		self::$arg = $arg;
		self::$type = 'edit';
		self::$class = [];

		self::Frame_Field_Start();
		?>

        <div class="ytpl-preview">
            <video controls>
                <source src="<?php echo esc_url( wp_get_attachment_url( self::Arg( 'video' ) ) ); ?>" type="video/mp4">
            </video>
        </div>
        <div class="ytpl-options">
            <div>
                <div class="ytpl-option" data-name="link">
					<?php echo VPP_ICON::$help; ?>
                    <span><?php echo __( 'Link', VPP_TEXT_DOMAIN ); ?></span>
					<?php echo VPP_ICON::$plus; ?>
                </div>
            </div>
            <div class="ytpl-element">
				<?php

				if ( ! empty( self::Arg( 'data' ) ) ):
					foreach ( self::Arg( 'data' )[0]['value'] as $index => $value ): ?>

                        <div class="ytpl-element-option">
                            <div class="ytpl-title"><?php echo __( 'Link', VPP_TEXT_DOMAIN ); ?></div>
                            <div class="ytpl-options">
                                <div class="ytpl-time">
                                    <div>
                                        <div class="ytpl-field ytpl-field-text">
                                            <label><?php echo __( 'Start Time', VPP_TEXT_DOMAIN ); ?></label>
                                            <input type="text" name="start-time"
                                                   value="<?php echo esc_attr( $value['start-time'] ); ?>">
                                        </div>
                                    </div>
                                    <div>
                                        <button><?php echo __( 'Set Current Time', VPP_TEXT_DOMAIN ); ?></button>
                                    </div>
                                </div>
                                <div class="ytpl-time">
                                    <div>
                                        <div class="ytpl-field ytpl-field-text">
                                            <label><?php echo __( 'End Time', VPP_TEXT_DOMAIN ); ?></label>
                                            <input type="text" name="end-time"
                                                   value="<?php echo esc_attr( $value['end-time'] ); ?>">
                                        </div>
                                    </div>
                                    <div>
                                        <button><?php echo __( 'Set Current Time', VPP_TEXT_DOMAIN ); ?></button>
                                    </div>
                                </div>
                                <div class="ytpl-field ytpl-field-text">
                                    <label><?php echo __( 'Title', VPP_TEXT_DOMAIN ); ?></label>
                                    <input type="text" name="title" value="<?php echo esc_attr( $value['title'] ); ?>">
                                </div>
                                <div class="ytpl-field ytpl-field-text">
                                    <label><?php echo __( 'Link', VPP_TEXT_DOMAIN ); ?></label>
                                    <input type="text" name="link" value="<?php echo esc_attr( $value['link'] ); ?>">
                                </div>
                            </div>
							<?php

							self::Input(
								[
									'type'  => 'hidden',
									'name'  => esc_attr( $index ),
									'value' => json_encode( $value ),
									'class' => [
										self::__save
									]
								]
							);

							?>
                        </div>

					<?php endforeach;
				endif;

				?>
            </div>
        </div>

		<?php
		self::Frame_Field_End();

	}

	/**
	 * Radio
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          description: String
	 *          default: String
	 *          options:
	 *              [
	 *                  $key: $text
	 *              ]
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Radio( $arg ) {

		self::$arg = $arg;
		self::$type = 'radio';
		self::$class = [];

		self::Frame_Field_Start();
		self::Heading();

		foreach ( self::Arg( 'options' ) as $index => $value ): ?>

            <div class="ytpl-option <?php echo $index == self::Arg( 'default' ) ? 'active' : ''; ?>"
                 value="<?php echo esc_attr( $index ); ?>">
                <div></div>
                <span><?php echo esc_html( $value ); ?></span>
            </div>

		<?php endforeach;

		self::Input(
			[
				'type'  => 'hidden',
				'name'  => self::Arg( 'name' ),
				'value' => self::Arg( 'default' ),
				'class' => [
					self::__save
				]
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Checkbox
	 *
	 *      [
	 *          name: String,
	 *          title: String,
	 *          active: Boolean
	 *      ]
	 *
	 * @param $arg
	 */
	public static function CheckBox( $arg ) {

		self::$arg = $arg;
		self::$type = 'checkbox';
		self::$class = [];

		self::Frame_Field_Start();
		?>

        <div class="ytpl-checkbox <?php echo esc_attr( self::Arg( 'active' ) == 'yes' ? 'active' : null ); ?>"></div>
        <span><?php echo esc_html( self::Arg( 'title' ) ); ?></span>

		<?php
		self::Input(
			[
				'type'  => 'hidden',
				'name'  => self::Arg( 'name' ),
				'value' => self::Arg( 'active' ),
				'class' => [
					self::__save
				]
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Video
	 *
	 *      [
	 *          name: String
	 *          video: String|Int
	 *          preview: Boolean
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Video( $arg ) {

		self::$arg = $arg;
		self::$type = 'video';
		self::$class = [];
		$video_url = '';
        $is_url = false;

        // check is not empty
        if(!empty(self::Arg( 'video' ))){
            // check is id or url
            if(is_numeric(self::Arg( 'video' ))){
                $video_url = wp_get_attachment_url( self::Arg( 'video' ) );
            }else{
                $video_url = self::Arg( 'video' );
                $is_url = true;
            }
        }

		self::Frame_Field_Start();
		?>


        <video controls>
            <source src="<?php echo esc_url( $video_url ); ?>" type="video/mp4">
        </video>
		<?php if ( ! self::Arg( 'preview' ) ): ?>
            <button class="ytpl-select <?php echo $is_url?'disable':''; ?>">
				<?php echo __( '👉 Click here to select the video 👈', VPP_TEXT_DOMAIN ); ?>
            </button>
            <input class="ytpl-link-select" type="url" placeholder="<?php echo __( '👉 Paste video link 👈', VPP_TEXT_DOMAIN ); ?>" value="<?php echo $is_url?$video_url:''; ?>"/>
		<?php endif; ?>
        <div class="ytpl-detail">
            <div class="ytpl-item">
                <div><?php echo __( 'Video Link', VPP_TEXT_DOMAIN ); ?>:</div>
                <a class="ytpl-link" style="color:#222;">
					<?php

					if ( $video_url ) {
						echo esc_url( $video_url );
					} else {
						echo __( 'First select video', VPP_TEXT_DOMAIN );
					}

					?>
                </a>
            </div>
            <div class="ytpl-item">
                <div><?php echo __( 'File Name', VPP_TEXT_DOMAIN ); ?>:</div>
                <a class="ytpl-filename">
					<?php

					if ( $video_url ) {

                        // check is url
                        if($is_url){
                          echo 'Video is url.';
                        } else {
							$filename = explode( '/', $video_url );
							echo esc_html( $filename[ count( $filename ) - 1 ] );
						}

					} else {
						echo __( 'First select video', VPP_TEXT_DOMAIN );
					}

					?>
                </a>
            </div>
        </div>

		<?php
		if ( ! self::Arg( 'preview' ) ) {
			self::Input(
				[
					'type'  => 'hidden',
					'class' => [
						self::__save
					],
					'name'  => self::Arg( 'name' ),
					'value' => self::Arg( 'video' ),
				]
			);
		}
		self::Frame_Field_End();

	}

	/**
	 * Quality
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Quality( $arg ) {

		self::$arg = $arg;
		self::$type = 'quality';
		self::$class = [];

		$quality_value = self::Arg( 'value' )['value'];
		$quality = [
			'2160' => '(4K)',
			'1440' => '(HD)',
			'1080' => '(HD)',
			'720'  => null,
			'480'  => null,
			'360'  => null,
			'240'  => null,
			'144'  => null,
		];

		self::Frame_Field_Start();
		self::Heading();
		?>

        <div class="ytpl-options">
			<?php foreach ( $quality as $index => $value ):

				$id = '--';
				$url = '----';
				$file_name = '-----';

				if ( ! empty( $quality_value[ $index ] ) ) {

					$id = $quality_value[ $index ];
					$url = wp_get_attachment_url( $id );
					$temp = explode( '/', $url );
					$file_name = $temp[ count( $temp ) - 1 ];

				}

				?>

                <div class="ytpl-item"
                     data-cell="<?php echo esc_attr( $index ); ?>" <?php echo ! empty( $quality_value[ $index ] ) ? 'data-id="' . esc_attr( $quality_value[ $index ] ) . '"' : null; ?>>
                    <div>
                        <button>
							<?php echo __( 'Select File', VPP_TEXT_DOMAIN ); ?>
							<?php echo ! empty( $value ) ? esc_html( $value ) : null; ?>
                            <div><?php echo esc_html( $index ); ?>p</div>
                        </button>
                    </div>
                    <div>
                        <div class="ytpl-filename">
                            #(<?php echo esc_html( $id ); ?>) -
							<?php echo esc_html( $file_name ); ?>
                        </div>
                        <a href="#" class="ytpl-fileurl">
							<?php echo esc_url( $url ); ?>
                        </a>
                    </div>
                    <div style="align-self: center">
						<?php echo VPP_ICON::$trash; ?>
                    </div>
                </div>

			<?php endforeach; ?>
        </div>

		<?php
		self::Input(
			[
				'type'  => 'hidden',
				'name'  => self::Arg( 'name' ),
				'value' => json_encode( self::Arg( 'value' )['value'] ),
				'class' => [
					self::__save
				]
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Tags
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          help: String
	 *          value: String
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Tags( $arg ) {

		self::$arg = $arg;
		self::$type = 'tags';
		self::$class = [];
		$val = self::Arg( 'value' ) ? self::Arg( 'value' ) : [];

		self::Frame_Field_Start();
		self::Heading();
		self::Input(
			[
				'type'        => 'text',
				'class'       => [
					'enter-tag'
				],
				'placeholder' => __( 'Enter Text (Press the enter-key to add)', VPP_TEXT_DOMAIN ),
			]
		);
		?>

        <div class="ytpl-options">
			<?php if ( empty( $val ) ): ?>

                <div class="ytpl-empty">
					<?php echo __( 'Empty List', VPP_TEXT_DOMAIN ); ?>
                </div>

			<?php endif;

			foreach ( $val as $index => $value ):?>

                <div class="ytpl-item" data-text="<?php echo esc_html( $value ); ?>">
					<?php echo esc_html( $value ); ?>
                    <button>
						<?php echo VPP_ICON::$x; ?>
                    </button>
                </div>

			<?php endforeach; ?>
            <div class="clear"></div>
        </div>

		<?php
		self::Input(
			[
				'type'  => 'hidden',
				'name'  => self::Arg( 'name' ),
				'value' => json_encode( self::Arg( 'value' ) ? self::Arg( 'value' ) : [] ),
				'class' => [
					self::__save
				]
			]
		);
		self::Frame_Field_End();

	}

	/**
	 * Chart
	 *
	 *      [
	 *          name: String
	 *          title: String
	 *          help: String
	 *          value: String
	 *      ]
	 *
	 * @param $arg
	 *
	 * @version 1.0.0
	 *
	 */
	public static function Chart( $arg ) {

		self::$arg = $arg;
		self::$type = 'chart';
		self::$class[] = self::__boxed;
		$max = 0;
		$top = 0;
		$fixed = [];

		if ( self::Arg( 'set_default' ) ) {
			$fixed = [
				'page'       => [
					'value' => 0,
					'color' => '#621940'
				],
				'post'       => [
					'value' => 0,
					'color' => '#843b62'
				],
				'embed'      => [
					'value' => 0,
					'color' => '#f67e7d'
				],
				'suggestion' => [
					'value' => 0,
					'color' => '#ffb997'
				],
			];
		}

		foreach ( empty( self::Arg( 'chart' ) ) ? [] : self::Arg( 'chart' ) as $index => $value ) {

			$max += $value;
			$top = max( $value, $top );

			if ( in_array( $index, [ 'page', 'post', 'embed', 'suggestion' ] ) ) {

				$fixed[ $index ]['value'] = $value;
				continue;

			}

			$fixed[ $index ] = [
				'value' => $value,
				'color' => '#747474'
			];

		}

		self::Frame_Field_Start();
		?>

        <div class="ytpl-inner-content">
            <div class="ytpl-heading">
				<?php echo esc_html(self::Arg( 'title' )); ?>
                <div class="ytpl-stc">
                    <div><?php echo esc_html(self::Arg( 'general' )); ?></div>
                    <div>
                        <div class="ytpl-line">
		                    <?php foreach ( $fixed as $index => $value ) :

			                    if ( $value['value'] == 0 ) {
				                    continue;
			                    }

			                    ?>
                                <div style="width:<?php echo esc_html($value['value'] * 100 / $max); ?>%; background-color:<?php echo esc_attr($value['color']); ?>;"></div>
		                    <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
			<?php

			// Empty
			if ( empty( $fixed ) ): ?>
                <div class="ytpl-empty">
					<?php echo __( 'Empty', VPP_TEXT_DOMAIN ); ?>
                </div>
			<?php endif;

			// Line chart
			if ( self::Arg( 'set_default' ) ): ?>

                <!-- Page -->
                <div class="ytpl-stc">
                    <div>
                        <div class="ytpl-color"
                             style="background-color: <?php echo esc_attr($fixed['page']['color']); ?>;"></div>
						<?php echo __( 'Page', VPP_TEXT_DOMAIN ); ?>
                    </div>
                    <div>
                        <span><?php echo floor( ! empty( $fixed['page']['value'] ) ? $fixed['page']['value'] * 100 / $max : 0 ); ?>%</span>
                        <div class="ytpl-line">
                            <div style="width:<?php echo ! empty( $fixed['page']['value'] ) ? $fixed['page']['value'] * 100 / $max : 0; ?>%; background-color:<?php echo $fixed['page']['color']; ?>;"></div>
                        </div>
                    </div>
                </div>

                <!-- Post -->
                <div class="ytpl-stc">
                    <div>
                        <div class="ytpl-color"
                             style="background-color: <?php echo $fixed['post']['color']; ?>;"></div>
						<?php echo __( 'Post', VPP_TEXT_DOMAIN ); ?>
                    </div>
                    <div>
                        <span><?php echo floor( ! empty( $fixed['post']['value'] ) ? $fixed['post']['value'] * 100 / $max : 0 ); ?>%</span>
                        <div class="ytpl-line">
                            <div style="width:<?php echo ! empty( $fixed['post']['value'] ) ? $fixed['post']['value'] * 100 / $max : 0; ?>%; background-color:<?php echo $fixed['post']['color']; ?>;"></div>
                        </div>
                    </div>
                </div>

                <!-- Embed -->
                <div class="ytpl-stc">
                    <div>
                        <div class="ytpl-color"
                             style="background-color: <?php echo esc_attr($fixed['embed']['color']); ?>;"></div>
						<?php echo __( 'Embed', VPP_TEXT_DOMAIN ); ?>
                    </div>
                    <div>
                        <span><?php echo floor( ! empty( $fixed['embed']['value'] ) ? $fixed['embed']['value'] * 100 / $max : 0 ); ?>%</span>
                        <div class="ytpl-line">
                            <div style="width:<?php echo ! empty( $fixed['embed']['value'] ) ? $fixed['embed']['value'] * 100 / $max : 0; ?>%; background-color:<?php echo $fixed['embed']['color']; ?>;"></div>
                        </div>
                    </div>
                </div>

                <!-- Suggestion -->
                <div class="ytpl-stc">
                    <div>
                        <div class="ytpl-color"
                             style="background-color: <?php echo esc_attr($fixed['suggestion']['color']); ?>;"></div>
						<?php echo __( 'Suggestion', VPP_TEXT_DOMAIN ); ?>
                    </div>
                    <div>
                        <span><?php echo floor( ! empty( $fixed['suggestion']['value'] ) ? $fixed['suggestion']['value'] * 100 / $max : 0 ); ?>%</span>
                        <div class="ytpl-line">
                            <div style="width:<?php echo ! empty( $fixed['suggestion']['value'] ) ? $fixed['suggestion']['value'] * 100 / $max : 0; ?>%; background-color:<?php echo $fixed['suggestion']['color']; ?>;"></div>
                        </div>
                    </div>
                </div>

			<?php endif;

			// More
			foreach ( $fixed as $index => $value ) :

				if ( in_array( $index, [ 'page', 'post', 'embed', 'suggestion' ] ) ) {
					continue;
				}

				?>

                <!-- <?php echo esc_html( $index ); ?> -->
                <div class="ytpl-stc">
                    <div>
                        <div class="ytpl-color" style="background-color: #747474;"></div>
						<?php echo esc_html( $index ); ?>
                    </div>
                    <div>
                        <span><?php echo floor( ! empty( $value['value'] ) ? $value['value'] * 100 / $max : 0 ); ?>%</span>
                        <div class="ytpl-line">
                            <div style="width:<?php echo ! empty( $value['value'] ) ? $value['value'] * 100 / $max : 0; ?>%"></div>
                        </div>
                    </div>
                </div>

			<?php endforeach;

			?>
        </div>

		<?php
		self::Frame_Field_End();

	}

	/**
	 * Group Start
	 */
public static function GroupStart() {
	?>

    <div class="ytpl-field ytpl-field-group">

		<?php
		}

		/**
		 * Group End
		 */
		public static function GroupEnd() {
		?>

    </div>

	<?php
}

	/**
	 * Input element
	 *
	 *      [
	 *          type: String
	 *          name: String
	 *          class: Array
	 *          value: String
	 *      ]
	 *
	 * @param array $attr
	 *
	 * @version 1.0.0
	 *
	 */
	private static function Input( $attr = [] ) {
		?>

        <input
                id="<?php echo esc_attr( self::_Empty( $attr['name'] ) ); ?>"
                class="<?php echo esc_html( join( ' ', self::_Empty( $attr['class'] ) ) ); ?>"
                type="<?php echo esc_attr( self::_Empty( $attr['type'] ) ); ?>"
                name="<?php echo esc_attr( self::_Empty( $attr['name'] ) ); ?>"
                placeholder="<?php echo esc_attr( self::_Empty( $attr['placeholder'] ) ); ?>"
                value="<?php echo esc_attr( self::_Empty( $attr['value'] ) ); ?>">

		<?php

	}

	/**
	 * Label
	 *
	 * @version 1.0.0
	 *
	 */
	private static function Label() {
		?>

        <label for="<?php echo esc_html( self::Arg( 'name' ) ); ?>">
			<?php

			echo esc_html( self::Arg( 'title' ) );
			if ( self::Arg( 'help' ) ): ?>

                <div class="ytpl-help" data-help="<?php echo esc_html( self::Arg( 'help' ) ); ?>">
					<?php echo VPP_ICON::$help; ?>
                </div>

			<?php
			endif;

			?>
        </label>

		<?php
	}

	/**
	 * Heading
	 *
	 * @version 1.0.0
	 *
	 */
	private static function Heading() {
		?>

        <div class="ytpl-title">
            <div><?php echo esc_html( self::Arg( 'title' ) ); ?></div>
			<?php

			if ( self::Arg( 'description' ) ): ?>
                <span><?php echo esc_html( self::Arg( 'description' ) ); ?></span>
			<?php
			endif;

			?>
        </div>

		<?php
	}

	/**
	 * Frame field start
	 *
	 * @version 1.0.0
	 *
	 */
private static function Frame_Field_Start() {
	?>

    <div class="ytpl-field ytpl-field-<?php echo esc_html( self::$type . ' ' . join( ' ', self::$class ) ) ?>">

		<?php
		}

		/**
		 * Frame field end
		 *
		 * @version 1.0.0
		 *
		 */
		private static function Frame_Field_End() {
		?>

    </div>

	<?php
}

	/**
	 * Arg
	 *
	 * @param $key
	 *
	 * @return mixed|null
	 * @version 1.0.0
	 *
	 */
	private static function Arg( $key ) {

		return self::_Empty( self::$arg[ $key ] );

	}

	/**
	 * Check isset variable and empty
	 *
	 * @param $variable
	 * @param $default
	 *
	 * @return mixed|null
	 * @version 1.0.0
	 *
	 */
	private static function _Empty( &$variable, $default = null ) {

		return isset( $variable ) ? ! empty( $variable ) ? $variable : $default : $default;

	}

	/**
	 * Check empty array
	 *
	 * @param $array
	 *
	 * @return array|null
	 * @version 1.0.0
	 *
	 */
	private static function CheckArray( $array ) {

		if ( ! empty( $array ) ) {
			return $array;
		}

		return [];

	}

}