<?php


class VPP_VIDEO_META {

	/**
	 * add meta
	 *
	 * @param $video_id int video id
	 * @param $name string name meta
	 * @param $value mixed value meta
	 *
	 * @return int|bool
	 *
	 */
	static function Add_Meta( int $video_id, string $name, $value ) {

		return VPP_DATABASE::Insert(
			'vpp_video_meta',
			[
				'object_id' => $video_id,
				'name'      => $name,
				'value'     => $value
			]
		);

	}

	/**
	 * get video meta
	 *
	 * @param $video_id int
	 * @param $name string
	 *
	 * @return array|mixed
	 *
	 */
	static function Get_Meta( int $video_id, string $name ) {

		$result = VPP_DATABASE::Select(
			'vpp_video_meta',
			[
				'where' => VPP_DATABASE::Where( [
					'condition' => [
						[
							'column' => 'object_id',
							'value'  => $video_id,
						],
						[
							'column' => 'name',
							'value'  => $name,
						],
					]
				] )
			]
		);

		if ( ! empty( $result ) ) {
			return $result[0]['value'];
		}

		return false;

	}

	/**
	 * update video meta
	 *
	 * @param int $video_id
	 * @param string $name
	 * @param string $value
	 * @param bool $auto_delete
	 *
	 * @return bool|int
	 */
	static function Update_Meta( int $video_id, string $name, string $value, $auto_delete = false ) {

		$exist_data = VPP_DATABASE::RowExist( 'vpp_video_meta', VPP_DATABASE::Where( [
			'condition' => [
				[
					'column' => 'object_id',
					'value'  => $video_id
				],
				[
					'column' => 'name',
					'value'  => $name
				],
			]
		] ) );

		if ( ! $exist_data ) {
			return self::Add_Meta( $video_id, $name, $value );
		}

		if ( empty( $value ) && $auto_delete ) {

			self::Delete_Meta( $video_id, $name );

			return false;

		}

		return VPP_DATABASE::Update(
			'vpp_video_meta',
			[
				'value' => $value
			],
			VPP_DATABASE::Where( [
				'condition' => [
					[
						'column' => 'object_id',
						'value'  => $video_id
					],
					[
						'column' => 'name',
						'value'  => $name
					],
				]
			] )
		);

	}

	/**
	 * Delete video meta
	 *
	 * @param $video_id
	 * @param $name
	 *
	 */
	static function Delete_Meta( $video_id, $name ) {

		VPP_DATABASE::Delete(
			'vpp_video_meta',
			VPP_DATABASE::Where( [
				'condition' => [
					[
						'column' => 'object_id',
						'value'  => $video_id
					],
					[
						'column' => 'name',
						'value'  => $name
					],
				]
			] )
		);

	}

	/**
	 * Delete all video meta
	 *
	 * @param $video_id
	 *
	 */
	static function Delete_All_Meta($video_id){

		VPP_DATABASE::Delete(
			'vpp_video_meta',
			VPP_DATABASE::Where( [
				'condition' => [
					[
						'column' => 'object_id',
						'value'  => $video_id
					],
				]
			] )
		);

	}

}