<?php


class VPP_PAGE_VIDEO {

	/** @var string $page_id page id */
	private $page_id = 'video';

	/**
	 * VPP_PAGE_VIDEO constructor.
	 */
	public function __construct() {

		/** menu */
		add_action( 'vpp_studio_menu', array( $this, 'Menu' ), 10 );

		/** Ajax */
		add_action( 'wp_ajax_vpp_page_' . $this->page_id, array( $this, 'Render' ) );
		add_action( 'wp_ajax_nopriv_vpp_page_' . $this->page_id, array( $this, 'Render' ) );

	}

	/**
	 * Menu
	 */
	public function Menu() {

		VPP_FUNCTION::Menu( $this->page_id, __( 'Video', VPP_TEXT_DOMAIN ), VPP_ICON::$video, true );

	}

	/**
	 * Render
	 */
	public function Render() {

		VPP_AJAX_NONCE::Nonce();

		add_filter( 'vpp_page_tabs_' . $this->page_id, array( $this, 'Tab_Config' ) );

		add_action( 'vpp_page_tabs_' . $this->page_id . '_shortcodes', array( $this, 'Shortcodes' ) );

		VPP_FUNCTION::Tabs( 'video', __( 'Your Video', VPP_TEXT_DOMAIN ) );

		die;

	}

	/**
	 * Tabs Config
	 *
	 * @param array $data
	 *
	 * @return mixed
	 *
	 */
	public function Tab_Config( $data ) {

		$data['shortcodes'] = __( 'Shortcodes', VPP_TEXT_DOMAIN );

		return $data;

	}

	/**
	 * Tab shortcodes
	 */
	public function Shortcodes() {

		$page = isset( $_REQUEST['page'] ) ? sanitize_text_field( $_REQUEST['page'] ) : 1;
		$per_page = isset( $_REQUEST['per_page'] ) ? sanitize_text_field( $_REQUEST['per_page'] ) : 10;

		$video = new VPP_VIDEO();
		$video->Config(
			[
				'current_page' => $page,
				'per_page'     => $per_page
			]
		);
		$video_more = $video->SelectMore();
		$video_count = $video->Count();
		$video_start = ( $page - 1 ) * $per_page;

		$column_table = apply_filters( 'vpp_studio_video_table_column',
			[
				'visibility' => __( 'Visibility', VPP_TEXT_DOMAIN ),
				'date'       => __( 'Date', VPP_TEXT_DOMAIN ),
			]
		);

		?>

        <div class="ytpl-table" data-action="ytpl_delete_group_video">
            <div class="ytpl-table-header">

                <div class="ytpl-table-cell"
                     style="margin-top:3px; min-width: 32px; padding-left: 24px; padding-right: 4px; flex: 0 0 32px;">
					<?php VPP_FIELD::CheckBox(
						[
							'name' => 'all'
						]
					); ?>
                </div>

                <div class="ytpl-table-cell"
                     style="min-width:382px; padding-left:12px; padding-right:0; flex:3 0 382px; left:60px;">
					<?php echo __( 'Video', VPP_TEXT_DOMAIN ); ?>
                </div>

				<?php

				foreach ( $column_table as $index => $val ):

					switch ( $index ):

						case 'visibility': ?>

                            <div class="ytpl-table-cell"
                                 style="min-width:100px;padding-left:24px;padding-right:8px;flex:1 0 100px;">
								<?php echo esc_html( $val ); ?>
                            </div>

							<?php break;

						case 'date': ?>

                            <div class="ytpl-table-cell"
                                 style="min-width:100px;padding-left:12px;padding-right:12px;flex:0 0 100px;">
								<?php echo esc_html( $val ); ?>
                            </div>

							<?php break;

						case 'view':
						case 'comment': ?>

                            <div class="ytpl-table-cell"
                                 style="min-width:26px;padding-left:12px;padding-right:12px;flex:1 0 26px;">
								<?php echo esc_html( $val ); ?>
                            </div>

							<?php break;

						case 'like': ?>

                            <div class="ytpl-table-cell"
                                 style="min-width:60px;padding-left:12px;padding-right:12px;flex:1 0 60px;">
								<?php echo esc_html( $val ); ?>
                            </div>

							<?php break;

						default: ?>

                            <div class="ytpl-table-cell"
                                 style="min-width:80px;padding-left:12px;padding-right:12px;flex:0 0 80px;">
								<?php echo esc_html( $val ); ?>
                            </div>

							<?php break;

					endswitch;

				endforeach;

				?>
            </div>
            <div class="ytpl-table-body">

				<?php

				if ( empty( $video_more ) ):
					?>

                    <div class="ytpl-empty">
						<?php echo __( 'Empty List', VPP_TEXT_DOMAIN ); ?>
                    </div>

				<?php
				endif;

				foreach ( $video_more as $index => $value ): ?>

                    <div class="ytpl-table-row">

                        <div class="ytpl-table-cell"
                             style="min-width: 32px; padding-left: 24px; padding-right: 4px; flex: 0 0 32px;">
							<?php VPP_FIELD::CheckBox(
								[
									'name' => $value['id']
								]
							); ?>
                        </div>

                        <div class="ytpl-table-cell"
                             style="min-width:382px; padding-left:12px; padding-right:0; flex:3 0 382px; left:60px;">
                            <div class="ytpl-video-detail">
                                <div class="ytpl-video-cover-mini"
                                     style="background:url(<?php echo esc_url( wp_get_attachment_image_url( $value['thumbnail'], 'full' ) ); ?>)"></div>
                                <div class="ytpl-video-detail-content">
                                    <div><?php echo esc_html( $value['title'] ); ?></div>
                                    <span><?php echo esc_html( $value['description'] ); ?></span>
                                    <div class="ytpl-options">
                                        <button id="ytpl_edit_video"
                                                data-id="<?php echo esc_attr( $value['id'] ); ?>"><?php echo VPP_ICON::$edit; ?></button>
                                        <button id="ytpl_video_delete"
                                                data-id="<?php echo esc_attr( $value['id'] ); ?>"><?php echo VPP_ICON::$trash; ?></button>
										<?php

										/** do_action vpp studio video table button */
										do_action( 'vpp_studio_video_table_buttons', $value );

										?>
                                    </div>
                                </div>
                            </div>
                        </div>

						<?php

						foreach ( $column_table as $key => $val ):

							switch ( $key ):

								case 'visibility': ?>

                                    <div class="ytpl-table-cell"
                                         style="min-width:100px;padding-left:24px;padding-right:8px;flex:1 0 100px;">
                                        <div class="ytpl-visibility <?php echo esc_attr( $value['visibility'] ); ?>">
											<?php echo VPP_ICON::$eye; ?>
                                            <span>
                                            <?php

                                            switch ( $value['visibility'] ) {
	                                            case 'private':
		                                            echo __( 'Private', VPP_TEXT_DOMAIN );
		                                            break;
	                                            default:
		                                            echo __( 'Public', VPP_TEXT_DOMAIN );
                                            }

                                            ?>
                                        </span>
                                        </div>
                                    </div>

									<?php break;

								case 'date': ?>

                                    <div class="ytpl-table-cell"
                                         style="min-width:100px;padding-left:12px;padding-right:12px;flex:0 0 100px;">
                                        <div class="ytpl-view-date">
                                            <div><?php echo date( 'M d, Y', $value['time'] ) ?></div>
                                            <span><?php echo __( 'Published', VPP_TEXT_DOMAIN ); ?></span>
                                        </div>
                                    </div>

									<?php break;

							endswitch;

						endforeach;

						do_action( 'vpp_studio_video_table_column_content', [
							'column' => $column_table,
							'video'  => $value
						] );

						?>
                    </div>

				<?php endforeach; ?>

            </div>
            <div class="ytpl-table-pagination">
                <div class="ytpl-nav">
                    <div class="ytpl-icon-button"
                         data-page="<?php echo ceil( $video_count / $per_page ); ?>">
						<?php echo VPP_ICON::$nav_end; ?>
                    </div>
                    <div class="ytpl-icon-button" <?php echo( $video_start + count( $video_more ) < $video_count ? 'data-page="' . ( $page + 1 ) . '"' : '' ); ?>>
						<?php echo VPP_ICON::$nav_next; ?>
                    </div>
                    <div class="ytpl-icon-button" <?php echo( $page > 1 ? 'data-page="' . ( $page - 1 ) . '"' : '' ); ?>>
						<?php echo VPP_ICON::$nav_prev; ?>
                    </div>
                    <div class="ytpl-icon-button" data-page="1">
						<?php echo VPP_ICON::$nav_start; ?>
                    </div>
                </div>
                <div class="ytpl-count-item">
					<?php echo esc_html( ( $video_start + 1 ) . '-' . ( $video_start + count( $video_more ) ) ); ?>
					<?php echo __( 'of', VPP_TEXT_DOMAIN ); ?>
					<?php echo esc_html( $video_count ); ?>
                </div>
                <div class="ytpl-per-page">
                    <span><?php echo __( 'Rows per page', VPP_TEXT_DOMAIN ); ?>:</span>
                    <select>
                        <option <?php echo $per_page == '10' ? 'selected="true"' : ''; ?>>10</option>
                        <option <?php echo $per_page == '30' ? 'selected="true"' : ''; ?>>30</option>
                        <option <?php echo $per_page == '50' ? 'selected="true"' : ''; ?>>50</option>
                    </select>
                </div>
            </div>
        </div>

		<?php

	}

}

new VPP_PAGE_VIDEO();