<?php


class VPP_PAGE_VIDEO_EDIT {

	/** @var string $page_id page id */
	private $page_id = 'video_edit';

	/** @var null|VPP_VIDEO video */
	private $video = null;

	/** @var null|array video selected */
	private $video_selected = null;

	/**
	 * VPP_PAGE_VIDEO constructor.
	 */
	public function __construct() {

		/** Ajax */
		add_action( 'wp_ajax_vpp_page_' . $this->page_id, array( $this, 'Render' ) );
		add_action( 'wp_ajax_nopriv_vpp_page_' . $this->page_id, array( $this, 'Render' ) );

	}

	/**
	 * Render
	 */
	public function Render() {

		VPP_AJAX_NONCE::Nonce();

		$request = isset( $_REQUEST['config'] ) ? sanitize_text_field( $_REQUEST['config'] ) : [];
		$config = json_decode( stripslashes( $request ) );
		$this->video = new VPP_VIDEO( $config->id );
		$this->video_selected = $this->video->Select();

		add_filter( 'vpp_page_tabs_' . $this->page_id, array( $this, 'Tab_Config' ) );

		add_action( 'vpp_page_tabs_' . $this->page_id . '__tab', array( $this, 'Save_Button' ) );
		add_action( 'vpp_page_tabs_' . $this->page_id . '_details', array( $this, 'Details' ) );
		add_action( 'vpp_page_tabs_' . $this->page_id . '_visibility', array( $this, 'Visibility' ) );
		add_action( 'vpp_page_tabs_' . $this->page_id . '_info', array( $this, 'Info' ) );

		VPP_FUNCTION::Tabs( 'video_edit', '#' . esc_html( $this->video_selected['id'] ) . ' - ' . esc_html( $this->video_selected['title'] ), $this->video );

		die;

	}

	/**
	 * Tab config
	 *
	 * @param array $data
	 *
	 * @return mixed
	 *
	 */
	public function Tab_Config( $data ) {

		$data['details'] = __( 'Details', VPP_TEXT_DOMAIN );
		$data['visibility'] = __( 'Visibility', VPP_TEXT_DOMAIN );
		$data['info'] = __( 'Info', VPP_TEXT_DOMAIN );

		return $data;

	}

	/**
	 * Save Button
	 */
	public function Save_Button() {

		?>

        <button class="ytpl-save" id="ytpl_save_update_video">
			<?php echo __( 'Save', VPP_TEXT_DOMAIN ); ?>
        </button>

		<?php

	}

	/**
	 * Tab details
	 */
	public function Details() {

		?>

        <div class="ytpl-edit-video-panel">
            <div>
				<?php

				VPP_FIELD::TextBox(
					[
						'name'  => 'title',
						'title' => __( 'Title', VPP_TEXT_DOMAIN ),
						'value' => $this->video_selected['title']
					]
				);

				VPP_FIELD::Text_Area(
					[
						'name'  => 'description',
						'title' => __( 'Description', VPP_TEXT_DOMAIN ),
						'value' => $this->video_selected['description']
					]
				);

				VPP_FIELD::Thumbnail(
					[
						'name'        => 'thumbnail',
						'title'       => __( 'Thumbnail', VPP_TEXT_DOMAIN ),
						'description' => __( 'Select a picture that show whats in your video. A good thumbnail stands out and draws viewers attention.', VPP_TEXT_DOMAIN ),
						'value'       => $this->video_selected['thumbnail']
					]
				);

				/** do_action vpp studio video edit detail before */
				do_action( 'vpp_studio_video_edit_detail_before', $this->video, $this->video_selected );

				$tag = new VPP_VIDEO_TAG();
				$tag->Video_ID = $this->video->ID;
				VPP_FIELD::Tags(
					[
						'name'        => 'tags',
						'title'       => __( 'Tags', VPP_TEXT_DOMAIN ),
						'description' => __( 'To add the text tag in the text box and enter inter.', VPP_TEXT_DOMAIN ),
						'value'       => $tag->SelectByVideoID()
					]
				);

				/** do_action vpp studio video edit detail after */
				do_action( 'vpp_studio_video_edit_detail_after', $this->video, $this->video_selected );

				?>
            </div>
            <div>
				<?php

				VPP_FIELD::Video(
					[
						'name'   => 'video',
						'video'  => $this->video_selected['video'],
						'active' => false
					]
				);

				?>
            </div>
        </div>

		<?php

	}

	/**
	 * Tab visibility
	 */
	public function Visibility() {

		?>

        <div class="ytpl-edit-video-panel">
            <div>
				<?php

				$visibility = apply_filters('vpp_studio_video_edit_visibility_option',[
					'public'  => __( 'Public', VPP_TEXT_DOMAIN ),
					'private' => __( 'Private', VPP_TEXT_DOMAIN ),
				]);

				VPP_FIELD::Radio(
					[
						'name'        => 'visibility',
						'title'       => __( 'Visibility', VPP_TEXT_DOMAIN ),
						'description' => __( 'Put your video in both public and private mode. Public mode is used for public mode and private mode is displayed for users who have entered the site.', VPP_TEXT_DOMAIN ),
						'default'     => $this->video_selected['visibility'],
						'options'     => $visibility
					]
				);

				/** do_action vpp studio video edit visibility */
				do_action( 'vpp_studio_video_edit_visibility', $this->video, $this->video_selected );

				?>
            </div>
            <div>
				<?php

				VPP_FIELD::Video(
					[
						'name'    => 'video',
						'video'   => $this->video_selected['video'],
						'preview' => true
					]
				);

				?>
            </div>
        </div>

		<?php

	}

	/**
	 * Tab info
	 */
	public function Info() {

		?>

        <div class="ytpl-panel-info" style="padding:24px;">
            <table>
                <tr>
                    <td><?php echo __( 'Shortcode', VPP_TEXT_DOMAIN ) ?></td>
                    <td>
                        <input disabled
                               value='[vlnd_player id="<?php echo esc_html( $this->video_selected['id'] ) ?>"]'>
                    </td>
                </tr>
            </table>
			<?php

			/** do_action vpp studio video edit info */
			do_action( 'vpp_studio_video_edit_info', $this->video, $this->video_selected );

			?>
        </div>

		<?php

	}

}

new VPP_PAGE_VIDEO_EDIT();